@@ -568,8 +568,20 @@ where
     fn emit_big_lit(&mut self, v: &BigInt) -> Result {
         self.emit_leading_comments_of_span(v.span, false)?;
 
-        self.wr.write_lit(v.span, &v.value.to_string())?;
-        self.wr.write_lit(v.span, "n")?;
+        if self.cfg.minify {
+            self.wr.write_lit(v.span, &v.value.to_string())?;
+            self.wr.write_lit(v.span, "n")?;
+        } else {
+            match &v.raw {
+                Some(raw) => {
+                    self.wr.write_lit(v.span, raw)?;
+                }
+                _ => {
+                    self.wr.write_lit(v.span, &v.value.to_string())?;
+                    self.wr.write_lit(v.span, "n")?;
+                }
+            }
+        }
     }
 
     // fn emit_object_binding_pat(&mut self, node: &ObjectPat) -> Result {
@@ -3324,23 +3336,38 @@ fn get_quoted_utf16(v: &str, target: EsVersion) -> String {
 
                 match next {
                     // TODO fix me - workaround for surrogate pairs
-                    Some('\x00') => {
+                    Some('u') => {
                         let mut inner_iter = iter.clone();
 
                         inner_iter.next();
 
-                        let next = inner_iter.peek();
+                        let mut is_curly = false;
+                        let mut next = inner_iter.peek();
+
+                        if next == Some(&'{') {
+                            is_curly = true;
 
-                        if let Some('u') = next {
                             inner_iter.next();
+                            next = inner_iter.peek();
+                        }
 
-                            let mut is_valid = true;
+                        if let Some(c @ 'D' | c @ 'd') = next {
                             let mut inner_buf = String::new();
 
                             inner_buf.push('\\');
                             inner_buf.push('u');
 
-                            for _ in 0..4 {
+                            if is_curly {
+                                inner_buf.push('{');
+                            }
+
+                            inner_buf.push(*c);
+
+                            inner_iter.next();
+
+                            let mut is_valid = true;
+
+                            for _ in 0..3 {
                                 let c = inner_iter.next();
 
                                 match c {
@@ -3355,13 +3382,21 @@ fn get_quoted_utf16(v: &str, target: EsVersion) -> String {
                                 }
                             }
 
+                            if is_curly {
+                                inner_buf.push('}');
+                            }
+
                             if is_valid {
                                 buf.push_str(&inner_buf);
 
-                                for _ in 0..6 {
+                                let end = if is_curly { 7 } else { 5 };
+
+                                for _ in 0..end {
                                     iter.next();
                                 }
                             }
+                        } else {
+                            buf.push_str("\\\\");
                         }
                     }
                     _ => {
